@@ -47,7 +47,21 @@ class SocketServer_Multiplex(object):
         log.debug("selector implementation: %s.%s", self.selector.__class__.__module__, self.selector.__class__.__name__)
         self.sock = None
         bind_location = unixsocket if unixsocket else (host, port)
-        self.sock = socketutil.createSocket(bind=bind_location, reuseaddr=config.SOCK_REUSE, timeout=config.COMMTIMEOUT, noinherit=True, nodelay=config.SOCK_NODELAY)
+        if config.SSL:
+            sslContext = socketutil.getSSLcontext(servercert=config.SSL_SERVERCERT,
+                                                  serverkey=config.SSL_SERVERKEY,
+                                                  keypassword=config.SSL_SERVERKEYPASSWD,
+                                                  cacerts=config.SSL_CACERTS)
+            log.info("using SSL,  cert=%s  key=%s  cacerts=%s", config.SSL_SERVERCERT, config.SSL_SERVERKEY, config.SSL_CACERTS)
+        else:
+            sslContext = None
+            log.info("not using SSL")
+        self.sock = socketutil.createSocket(bind=bind_location,
+                                            reuseaddr=config.SOCK_REUSE,
+                                            timeout=config.COMMTIMEOUT,
+                                            noinherit=True,
+                                            nodelay=config.SOCK_NODELAY,
+                                            sslContext=sslContext)
         self.daemon = daemon
         self._socketaddr = sockaddr = self.sock.getsockname()
         if not unixsocket and sockaddr[0].startswith("127."):
@@ -65,7 +79,7 @@ class SocketServer_Multiplex(object):
         self.selector.register(self.sock, selectors.EVENT_READ, self)
 
     def __repr__(self):
-        return "<%s on %s; %d connections>" % (self.__class__.__name__, self.locationStr, len(self.selector.get_map())-1)
+        return "<%s on %s; %d connections>" % (self.__class__.__name__, self.locationStr, len(self.selector.get_map()) - 1)
 
     def __del__(self):
         if self.sock is not None:
@@ -100,19 +114,21 @@ class SocketServer_Multiplex(object):
             if sock is None:
                 return
             csock, caddr = sock.accept()
-            log.debug("connected %s", caddr)
+            if hasattr(csock, "getpeercert"):
+                log.debug("connected %s - SSL", caddr)
+            else:
+                log.debug("connected %s - unencrypted", caddr)
             if config.COMMTIMEOUT:
                 csock.settimeout(config.COMMTIMEOUT)
-        except socket.error as x:
+        except (socket.error, OSError) as x:
             err = getattr(x, "errno", x.args[0])
-            if err in socketutil.ERRNO_RETRIES:
-                # just ignore this error for now and continue
-                log.warning("accept() failed errno=%d, shouldn't happen", err)
-                return None
             if err in socketutil.ERRNO_BADF or err in socketutil.ERRNO_ENOTSOCK:
                 # our server socket got destroyed
                 raise errors.ConnectionClosedError("server socket closed")
-            raise
+            # socket errors may not lead to a server abort, so we log it and continue
+            err = getattr(x, "errno", x.args[0])
+            log.warning("accept() failed '%s' with errno=%d, shouldn't happen", x, err)
+            return None
         try:
             conn = socketutil.SocketConnection(csock)
             if self.daemon._handshake(conn):
@@ -142,7 +158,7 @@ class SocketServer_Multiplex(object):
             sockname = None
             try:
                 sockname = self.sock.getsockname()
-            except socket.error:
+            except (socket.error, OSError):
                 pass
             self.sock.close()
             if type(sockname) is str:
